(napari-tutorials)=
# napari tutorials

These tutorials will help you explore the main usage modes and methods of
napari, and target people who want to use napari. If you are also interested
in contributing to napari then please check out [the Community page](../community/index).

::::{grid}
:::{grid-item-card} Annotation
:link: annotation
:link-type: ref

How to annotate images and videos using the napari points, labels, or shapes layers
:::

:::{grid-item-card} Processing
:link: processing
:link-type: ref

Data processing with napari
:::
::::

::::{grid}
:::{grid-item-card} Segmentation
:link: segmentation
:link-type: ref

Segmentation labeling with napari
:::

:::{grid-item-card} Tracking
:link: tracking
:link-type: ref

How to work with object tracking data and how to format it for display as a napari tracks layer.
:::
::::

## Improving the tutorials

Our tutorials are hosted on [the napari Github repository](https://github.com/napari/napari).
As you make your way through the tutorials, if you spot any errors or areas that
can be improved, please raise an issue on the repository or make a pull
request! We love it when our community helps make them better for everyone!
To see how to modify documentation pages, please see our
[documentation contributing guide](../developers/documentation/index).